# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot

snapshots = Snapshot()

snapshots["test_query_all_documents[integer-None-1-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "IntegerAnswer",
                                    "integer_value": 1,
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[float-None-2.1-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "FloatAnswer",
                                    "float_value": 2.1,
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[text-None-somevalue-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "StringAnswer",
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                    "string_value": "somevalue",
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[multiple_choice-None-answer__value3-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "ListAnswer",
                                    "list_value": ["somevalue", "anothervalue"],
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[table-None-None-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "TableAnswer",
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                    "table_value": [{"form": {"slug": "effort-meet"}}],
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "872d1b6f-790c-473c-b5e9-2e714d607695",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[date-None-None-2019-02-22] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "DateAnswer",
                                    "date_value": "2019-02-22",
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[file-None-some-file.pdf-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "FileAnswer",
                                    "fileValue": {
                                        "downloadUrl": "http://minio/download-url/09c697fb-fd0a-4345-bb9c-99df350b0cdb_some-file.pdf",
                                        "metadata": {
                                            "bucket_name": "caluma-media",
                                            "content_type": "application/pdf",
                                            "etag": "0c81da684e6aaef48e8f3113e5b8769b",
                                            "is_dir": False,
                                            "last_modified": (
                                                2019,
                                                4,
                                                5,
                                                7,
                                                0,
                                                49,
                                                4,
                                                95,
                                                0,
                                            ),
                                            "metadata": {
                                                "X-Amz-Meta-Testtag": "super_file"
                                            },
                                            "object_name": "some-file.pdf",
                                            "size": 8200,
                                        },
                                        "name": "some-file.pdf",
                                    },
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[file-None-some-other-file.pdf-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "FileAnswer",
                                    "fileValue": {
                                        "downloadUrl": "http://minio/download-url/09c697fb-fd0a-4345-bb9c-99df350b0cdb_some-other-file.pdf",
                                        "metadata": {
                                            "bucket_name": "caluma-media",
                                            "content_type": "application/pdf",
                                            "etag": "0c81da684e6aaef48e8f3113e5b8769b",
                                            "is_dir": False,
                                            "last_modified": (
                                                2019,
                                                4,
                                                5,
                                                7,
                                                0,
                                                49,
                                                4,
                                                95,
                                                0,
                                            ),
                                            "metadata": {
                                                "X-Amz-Meta-Testtag": "super_file"
                                            },
                                            "object_name": "some-file.pdf",
                                            "size": 8200,
                                        },
                                        "name": "some-other-file.pdf",
                                    },
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots["test_query_all_documents[dynamic_choice-MyDataSource-5.5-None] 1"] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "StringAnswer",
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                    "string_value": "5.5",
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots[
    "test_query_all_documents[dynamic_multiple_choice-MyDataSource-answer__value9-None] 1"
] = {
    "allDocuments": {
        "edges": [
            {
                "node": {
                    "answers": {
                        "edges": [
                            {
                                "node": {
                                    "__typename": "ListAnswer",
                                    "list_value": ["5.5"],
                                    "question": {
                                        "label": "Thomas Johnson",
                                        "slug": "sound-air-mission",
                                    },
                                }
                            }
                        ],
                        "totalCount": 1,
                    },
                    "createdByUser": "b24d3781-2f59-44c4-8602-cffe6aa89ae7",
                }
            }
        ],
        "totalCount": 1,
    }
}

snapshots[
    "test_save_document_answer[integer-question__configuration0-None-question__format_validators0-1-None-SaveDocumentIntegerAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentIntegerAnswer": {
        "answer": {"__typename": "IntegerAnswer", "integerValue": 1},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[integer-question__configuration0-None-question__format_validators0-1-None-SaveDocumentIntegerAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentIntegerAnswer": {
        "answer": {"__typename": "IntegerAnswer", "integerValue": 1},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[float-question__configuration2-None-question__format_validators2-2.1-None-SaveDocumentFloatAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentFloatAnswer": {
        "answer": {"__typename": "FloatAnswer", "floatValue": 2.1},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[float-question__configuration2-None-question__format_validators2-2.1-None-SaveDocumentFloatAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentFloatAnswer": {
        "answer": {"__typename": "FloatAnswer", "floatValue": 2.1},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[text-question__configuration4-None-question__format_validators4-Test-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "Test"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[text-question__configuration4-None-question__format_validators4-Test-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "Test"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[date-question__configuration7-None-question__format_validators7-None-2019-02-22-SaveDocumentDateAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentDateAnswer": {
        "answer": {"__typename": "DateAnswer", "dateValue": "2019-02-22"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[date-question__configuration7-None-question__format_validators7-None-2019-02-22-SaveDocumentDateAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentDateAnswer": {
        "answer": {"__typename": "DateAnswer", "dateValue": "2019-02-22"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[file-question__configuration9-None-question__format_validators9-some-file.pdf-None-SaveDocumentFileAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentFileAnswer": {
        "answer": {
            "__typename": "FileAnswer",
            "fileValue": {
                "name": "some-file.pdf",
                "uploadUrl": "http://minio/upload-url",
            },
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[file-question__configuration9-None-question__format_validators9-some-file.pdf-None-SaveDocumentFileAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentFileAnswer": {
        "answer": {
            "__typename": "FileAnswer",
            "fileValue": {
                "name": "some-file.pdf",
                "uploadUrl": "http://minio/upload-url",
            },
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[file-question__configuration10-None-question__format_validators10-not-exist.pdf-None-SaveDocumentFileAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentFileAnswer": {
        "answer": {
            "__typename": "FileAnswer",
            "fileValue": {
                "name": "not-exist.pdf",
                "uploadUrl": "http://minio/upload-url",
            },
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[file-question__configuration10-None-question__format_validators10-not-exist.pdf-None-SaveDocumentFileAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentFileAnswer": {
        "answer": {
            "__typename": "FileAnswer",
            "fileValue": {
                "name": "not-exist.pdf",
                "uploadUrl": "http://minio/upload-url",
            },
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[table-question__configuration12-None-question__format_validators12-None-None-SaveDocumentTableAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentTableAnswer": {
        "answer": {
            "__typename": "TableAnswer",
            "table_value": [
                {"form": {"slug": "suggest-traditional"}},
                {"form": {"slug": "suggest-traditional"}},
            ],
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[table-question__configuration12-None-question__format_validators12-None-None-SaveDocumentTableAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentTableAnswer": {
        "answer": {
            "__typename": "TableAnswer",
            "table_value": [
                {"form": {"slug": "suggest-traditional"}},
                {"form": {"slug": "suggest-traditional"}},
            ],
        },
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[textarea-question__configuration13-None-question__format_validators13-Test-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "Test"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[textarea-question__configuration13-None-question__format_validators13-Test-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "Test"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[multiple_choice-question__configuration15-None-question__format_validators15-answer__value15-None-SaveDocumentListAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentListAnswer": {
        "answer": {"__typename": "ListAnswer", "listValue": ["option-slug"]},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[multiple_choice-question__configuration15-None-question__format_validators15-answer__value15-None-SaveDocumentListAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentListAnswer": {
        "answer": {"__typename": "ListAnswer", "listValue": ["option-slug"]},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[choice-question__configuration17-None-question__format_validators17-option-slug-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "option-slug"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[choice-question__configuration17-None-question__format_validators17-option-slug-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "option-slug"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[dynamic_multiple_choice-question__configuration19-MyDataSource-question__format_validators19-answer__value19-None-SaveDocumentListAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentListAnswer": {
        "answer": {"__typename": "ListAnswer", "listValue": ["5.5", "1"]},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[dynamic_multiple_choice-question__configuration19-MyDataSource-question__format_validators19-answer__value19-None-SaveDocumentListAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentListAnswer": {
        "answer": {"__typename": "ListAnswer", "listValue": ["5.5", "1"]},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[dynamic_choice-question__configuration21-MyDataSource-question__format_validators21-5.5-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "5.5"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[dynamic_choice-question__configuration21-MyDataSource-question__format_validators21-5.5-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "5.5"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[text-question__configuration24-None-question__format_validators24-test@example.com-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "test@example.com"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[text-question__configuration24-None-question__format_validators24-test@example.com-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "test@example.com"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[textarea-question__configuration26-None-question__format_validators26-test@example.com-None-SaveDocumentStringAnswer-True-option-slug-True] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "test@example.com"},
        "clientMutationId": "testid",
    }
}

snapshots[
    "test_save_document_answer[textarea-question__configuration26-None-question__format_validators26-test@example.com-None-SaveDocumentStringAnswer-True-option-slug-False] 1"
] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": "test@example.com"},
        "clientMutationId": "testid",
    }
}

snapshots["test_save_document_answer_empty[text-false-None-True] 1"] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": None},
        "clientMutationId": None,
    }
}

snapshots["test_save_document_answer_empty[text-false-None-False] 1"] = {
    "saveDocumentStringAnswer": {
        "answer": {"__typename": "StringAnswer", "stringValue": None},
        "clientMutationId": None,
    }
}



import pytest

from ...caluma_core.tests import extract_serializer_input_fields
from .. import models, serializers


def test_save_option(db, option, snapshot, schema_executor):
    query = """
        mutation SaveOption($input: SaveOptionInput!) {
          saveOption(input: $input) {
            option {
              slug
              label
            }
          }
        }
    """

    inp = {
        "input": extract_serializer_input_fields(
            serializers.SaveOptionSerializer, option
        )
    }

    result = schema_executor(query, variables=inp)
    assert not result.errors
    snapshot.assert_match(result.data)


@pytest.mark.parametrize("option__meta", [{"meta": "set"}])
def test_copy_option(db, option, schema_executor):
    query = """
        mutation CopyOption($input: CopyOptionInput!) {
          copyOption(input: $input) {
            option {
              slug
            }
          }
        }
    """

    inp = {"input": {"source": option.pk, "slug": "new-option", "label": "Test Option"}}
    result = schema_executor(query, variables=inp)

    assert not result.errors

    option_slug = result.data["copyOption"]["option"]["slug"]
    assert option_slug == "new-option"
    new_option = models.Option.objects.get(pk=option_slug)
    assert new_option.label == "Test Option"
    assert new_option.meta == option.meta
    assert new_option.source == option


def test_dynamic_option(db, schema_executor, dynamic_option_factory):
    query = """
        query dynamicOptions ($filter:[DynamicOptionFilterSetType]) {
          allUsedDynamicOptions(filter: $filter){
            edges{
              node{
                slug
                label
              }
            }
          }
        }
    """

    dynamic_option = dynamic_option_factory()
    inp = {"filter": [{"document": dynamic_option.id}]}
    result = schema_executor(query, variables=inp)

    assert not result.errors
    assert dynamic_option.slug == "service-bank-arm"
    assert dynamic_option.label["en"] == "Calvin Graham"



# Generated by Django 2.2.4 on 2019-09-19 12:44
import logging

from django.db import migrations, models
from django.db.migrations import RunPython

from caluma.caluma_form.models import FormQuestion

logger = logging.getLogger(__name__)


def save_natural_keys(apps, schema_editor):
    for fq in FormQuestion.objects.all():
        FormQuestion.objects.filter(form=fq.form, question=fq.question).delete()
        fq.save()


def not_supported(apps, schema_editor):
    logger.warning("The reverse migration of this step is not supported.")


class Migration(migrations.Migration):

    dependencies = [("caluma_form", "0023_auto_20190729_1448")]

    operations = [
        migrations.AlterField(
            model_name="formquestion",
            name="id",
            field=models.CharField(
                max_length=255, primary_key=True, serialize=False, unique=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalformquestion",
            name="id",
            field=models.CharField(db_index=True, max_length=255),
        ),
        RunPython(save_natural_keys, not_supported),
    ]



# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot

snapshots = Snapshot()

snapshots["test_save_option 1"] = {
    "saveOption": {"option": {"label": "Brian Williams", "slug": "effort-meet"}}
}



# -*- coding: utf-8 -*-
# snapshottest: v1 - https://goo.gl/zC4yUc
from __future__ import unicode_literals

from snapshottest import Snapshot

snapshots = Snapshot()

snapshots["test_query_all_questions[multiple_choice-search_value0-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"question": "multiple_choice", "value": ["a", "b"]}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-EXACT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "EXACT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-STARTSWITH] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "STARTSWITH",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): STARTSWITH']\",)]",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-CONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "CONTAINS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-ICONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "ICONTAINS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "GTE", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "GT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): GT']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "LTE", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "LT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): LT']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"question": "multiple_choice", "value": ["a", "b"]}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "EXACT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-nomatch-STARTSWITH] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "STARTSWITH",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): STARTSWITH']\",)]",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-nomatch-CONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "CONTAINS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-nomatch-ICONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "ICONTAINS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "GTE", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "GT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): GT']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "LTE", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[multiple_choice-search_value0-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "LT", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=multiple_choice (MULTIPLE_CHOICE): LT']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "DIRECT", "question": "integer", "value": 10}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "DIRECT", "question": "integer", "value": 10}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "DIRECT", "question": "text", "value": "foo"}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[text-foo-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[text-foo-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[text-foo-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[text-foo-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): GT']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): LT']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "DIRECT", "question": "text", "value": "foo"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): GT']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): LT']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"hierarchy": "FAMILY", "question": "textarea", "value": "foo"}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): GT']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): LT']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"hierarchy": "FAMILY", "question": "textarea", "value": "foo"}
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): GT']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): LT']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "FAMILY", "question": "float", "value": 11.5}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"hierarchy": "FAMILY", "question": "float", "value": 11.5}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-None] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-EXACT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-STARTSWITH] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-CONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-ICONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-GTE] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-GT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-LTE] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-LT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-None] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-EXACT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "EXACT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-STARTSWITH] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "STARTSWITH",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-CONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "CONTAINS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-ICONTAINS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ICONTAINS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-GTE] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GTE",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-GT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "GT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-LTE] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LTE",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-LT] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "LT",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"hierarchy": "DIRECT", "question": "date", "value": "2018-05-09"}
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"hierarchy": "DIRECT", "question": "date", "value": "2018-05-09"}
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "EXACT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "STARTSWITH",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "CONTAINS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): CONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ICONTAINS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GTE",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "GT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LTE",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "LT",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-matching-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {"hasAnswer": [{"question": "choice", "value": "a"}]},
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[choice-a-matching-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "EXACT", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[choice-a-matching-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "STARTSWITH", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "CONTAINS", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[choice-a-matching-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "ICONTAINS", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "GTE", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "GT", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): GT']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "LTE", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "LT", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): LT']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-None] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {"hasAnswer": [{"question": "choice", "value": "a"}]},
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-nomatch-EXACT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "EXACT", "question": "choice", "value": "a"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-nomatch-STARTSWITH] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "STARTSWITH", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): STARTSWITH']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-CONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "CONTAINS", "question": "choice", "value": "a"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-nomatch-ICONTAINS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "ICONTAINS", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): ICONTAINS']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-GTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "GTE", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): GTE']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-GT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "GT", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): GT']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-LTE] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "LTE", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): LTE']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-LT] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "LT", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=choice (CHOICE): LT']\",)]",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-INTERSECTS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "INTERSECTS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-nomatch-INTERSECTS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "lookup": "INTERSECTS",
                    "question": "multiple_choice",
                    "value": ["a", "b"],
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[integer-10-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=integer (INTEGER): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[text-foo-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=text (TEXT): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[textarea-foo-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=textarea (TEXTAREA): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[float-11.5-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=float (FLOAT): INTERSECTS']\",)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-INTERSECTS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-INTERSECTS] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "INTERSECTS",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "INTERSECTS",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError(\"['Invalid lookup for question slug=date (DATE): INTERSECTS']\",)]",
    },
}

snapshots["test_query_all_questions[choice-a-matching-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "INTERSECTS", "question": "choice", "value": "a"}]
        },
    },
    "response": {
        "data": {"allDocuments": {"edges": [{"node": {"form": {"slug": "subform"}}}]}},
        "errors": "None",
    },
}

snapshots["test_query_all_questions[choice-a-nomatch-INTERSECTS] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "INTERSECTS", "question": "choice", "value": "a"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-matching-ISNULL] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "ISNULL", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[multiple_choice-search_value0-nomatch-ISNULL] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {"lookup": "ISNULL", "question": "multiple_choice", "value": ["a", "b"]}
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[integer-10-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "integer",
                    "value": 10,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[text-foo-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "text",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[textarea-foo-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "textarea",
                    "value": "foo",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[float-11.5-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "float",
                    "value": 11.5,
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-matching-ISNULL] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots[
    "test_query_all_questions[datetime-2018-05-09T14:54:51.728786-nomatch-ISNULL] 1"
] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "FAMILY",
                    "lookup": "ISNULL",
                    "question": "datetime",
                    "value": "2018-05-09T14:54:51.728786",
                }
            ]
        },
    },
    "response": {
        "data": {"allDocuments": None},
        "errors": "[GraphQLLocatedError('Question matching query does not exist.',)]",
    },
}

snapshots["test_query_all_questions[date-2018-05-09-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[date-2018-05-09-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [
                {
                    "hierarchy": "DIRECT",
                    "lookup": "ISNULL",
                    "question": "date",
                    "value": "2018-05-09",
                }
            ]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-matching-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "ISNULL", "question": "choice", "value": "a"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}

snapshots["test_query_all_questions[choice-a-nomatch-ISNULL] 1"] = {
    "request": {
        "query": """
        query asdf ($hasAnswer: [HasAnswerFilterType]!) {
          allDocuments(hasAnswer: $hasAnswer) {
            edges {
              node {
                form {
                  slug
                }
              }
            }
          }
        }
    """,
        "variables": {
            "hasAnswer": [{"lookup": "ISNULL", "question": "choice", "value": "a"}]
        },
    },
    "response": {"data": {"allDocuments": {"edges": []}}, "errors": "None"},
}
